summaryrefslogtreecommitdiff
path: root/noncore/graphics/opie-eye/lib/oimagezoomer.h
Side-by-side diff
Diffstat (limited to 'noncore/graphics/opie-eye/lib/oimagezoomer.h') (more/less context) (ignore whitespace changes)
-rw-r--r--noncore/graphics/opie-eye/lib/oimagezoomer.h13
1 files changed, 10 insertions, 3 deletions
diff --git a/noncore/graphics/opie-eye/lib/oimagezoomer.h b/noncore/graphics/opie-eye/lib/oimagezoomer.h
index 2516c61..0b356c9 100644
--- a/noncore/graphics/opie-eye/lib/oimagezoomer.h
+++ b/noncore/graphics/opie-eye/lib/oimagezoomer.h
@@ -73,3 +73,4 @@ signals:
* Here you get absolute coordinates.
* This slot will be emitted from within the mouseMoveEvent of this widget.
* So you may not delete this widget
@@ -100,3 +101,3 @@ protected:
*/
- void mousePressEvent( QMouseEvent* ev );
+ virtual void mousePressEvent( QMouseEvent* ev );
/**
@@ -105,3 +106,8 @@ protected:
*/
- void mouseMoveEvent( QMouseEvent* ev );
+ virtual void mouseMoveEvent( QMouseEvent* ev );
+ /**
+ * make sure to call these if you reimplement
+ * @internal
+ */
+ virtual void mouseReleaseEvent( QMouseEvent* ev );
@@ -116,2 +122,3 @@ private:
int m_mouseX, m_mouseY;
+ bool m_mevent;
};
@@ -73,3 +73,4 @@ signals:
* Here you get absolute coordinates.
- * This slot will be emitted from within the mouseMoveEvent of this widget.
+ * This slot will be emitted from within the mouseReleaseEvent of this widget.
+ * if no mouse move where done.
* So you may not delete this widget